"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const cli_ux_1 = tslib_1.__importDefault(require("cli-ux"));
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const guruClient_1 = tslib_1.__importDefault(require("../lib/guruClient"));
const helpers_1 = require("../lib/helpers");
exports.default = async (cli) => {
    cli.command('find <filter>', 'find cards based on search filter (full ECMAScript compliant regex supported)')
        .example(`Find all cards where content has 'delete me'
guru-cli find 'content:"delete me"'
`)
        .example(`Find all cards where collection has "Software" OR "Engineering" and title has "Overview"
guru-cli find 'collection:Software,Engineering title:Overview'
`)
        .example(`Find cards where verifier is EXACTLY "bob@example.com"
guru-cli find 'verifier:"^bob@example\\\\.com$"'
`)
        .option('-i, --ignore-case', 'Ignore case in the finding regex string')
        .action(async (filter, options) => {
        (0, helpers_1.checkAuth)();
        cli_ux_1.default.action.start('Searching for cards');
        const cardsRaw = await guruClient_1.default.getAllCardsRaw();
        const filteredCards = (0, helpers_1.handleCardsFilter)(filter, cardsRaw, options);
        if (!filteredCards.length) {
            cli_ux_1.default.action.stop(`❌ ${filteredCards.length} cards found matching your filter`);
            return;
        }
        cli_ux_1.default.action.stop(`✅  ${filteredCards.length} cards matching your filter\n---------------------------`);
        filteredCards.map((card) => console.log(`${chalk_1.default.bold.blueBright(card.title)} (${card.link})`));
    });
};
