"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const cli_ux_1 = tslib_1.__importDefault(require("cli-ux"));
const guruClient_1 = tslib_1.__importDefault(require("../lib/guruClient"));
const helpers_1 = require("../lib/helpers");
exports.default = async (cli) => {
    cli.command('verify-by-title <title>', 'Verifies cards by card title.')
        .option('--collection [collectionName]', 'Filter cards by collection.')
        .action(async (title, options) => {
        (0, helpers_1.checkAuth)();
        cli_ux_1.default.action.start('Searching for cards');
        const cardsRaw = await guruClient_1.default.getAllCardsRaw();
        let filteredCards = (0, helpers_1.handleCardsFilter)(`title:"^${title}$"`, cardsRaw, '-i');
        if (options.collection) {
            filteredCards = filteredCards.filter((card) => card.collection === options.collection);
        }
        if (!filteredCards.length) {
            cli_ux_1.default.action.stop(`❌ ${filteredCards.length} cards found matching your title`);
            return;
        }
        cli_ux_1.default.action.stop(`✅  ${filteredCards.length} card${filteredCards.length > 1 ? 's' : ''} match${filteredCards.length > 1 ? '' : 'es'} your collection and title\n---------------------------`);
        filteredCards.map((card) => console.log(`${chalk_1.default.bold.blueBright(card.collection)} ${chalk_1.default.bold.greenBright(card.title)} (${card.link})`));
        const confirm = await cli_ux_1.default.confirm('Do you wish to verify the identified card(s)? (Y/n)');
        if (!confirm)
            return;
        cli_ux_1.default.action.start(`Verifying ${title}`);
        for (const card of filteredCards) {
            await guruClient_1.default.verifyCardByID(card);
        }
    });
};
