"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const cli_progress_1 = tslib_1.__importDefault(require("cli-progress"));
const cli_ux_1 = tslib_1.__importDefault(require("cli-ux"));
const guruClient_1 = tslib_1.__importDefault(require("../lib/guruClient"));
const helpers_1 = require("../lib/helpers");
exports.default = async (cli) => {
    cli.command('verify-expired [filter]', 'Verifies all expired cards with optional filtering (see README)')
        .option('-i, --ignore-case', 'Ignore case in the finding regex string')
        .option('-f, --force', 'Skip confirmation, BE CAREFUL WITH THIS OPTION!')
        .action(async (filter, options) => {
        (0, helpers_1.checkAuth)();
        cli_ux_1.default.action.start('Gathering all expired cards');
        const expiredCards = await guruClient_1.default.getAllExpiredCardsRaw();
        const filteredCards = (0, helpers_1.handleCardsFilter)(filter, expiredCards, options);
        cli_ux_1.default.action.stop(`✅ ${filteredCards.length} expired cards found.`);
        if (!filteredCards.length) {
            console.log('You have no expired cards currently!');
            return;
        }
        console.log('Preview:\n------------------------');
        for (const card of filteredCards) {
            console.log(chalk_1.default.bold.blueBright(card.title));
        }
        if (!options.force) {
            const confirm = await cli_ux_1.default.confirm(`This will verify ${filteredCards.length} cards currently in expired state. Continue? (Y/n)`);
            if (!confirm)
                return;
        }
        const progress = new cli_progress_1.default.Bar({
            format: `Verifying Expired Cards ${chalk_1.default.hex('#7F4BAE')('{bar}')} {percentage}% | Current Card: {value}/{total} | Name: ${chalk_1.default.bold.hex('#D7E150')('{currentCard}')}`,
        }, cli_progress_1.default.Presets.shades_grey);
        progress.start(filteredCards.length, 0, { currentCard: '' });
        for (const card of filteredCards) {
            progress.increment(1, { currentCard: card.title });
            await guruClient_1.default.verifyCardByID(card);
        }
        progress.stop();
    });
};
