"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handleCardsFilter = exports.backupCards = exports.checkAuth = void 0;
const tslib_1 = require("tslib");
const path_1 = tslib_1.__importDefault(require("path"));
const promises_1 = tslib_1.__importDefault(require("fs/promises"));
const search_query_parser_1 = tslib_1.__importDefault(require("search-query-parser"));
const config_1 = tslib_1.__importDefault(require("../config"));
const guruClient_1 = tslib_1.__importDefault(require("./guruClient"));
function checkAuth() {
    if (!config_1.default.has('auth.email') || !config_1.default.has('auth.token')) {
        console.log('Please login first using "guru-cli login"');
        process.exit();
    }
}
exports.checkAuth = checkAuth;
async function backupCards(directoryPath) {
    const filePath = path_1.default.join(path_1.default.resolve(directoryPath), `/guru-cards-backup_${new Date().toJSON()}.json`);
    const cards = await guruClient_1.default.getAllCardsRaw();
    await promises_1.default.writeFile(filePath, JSON.stringify(cards, null, 4), 'utf8');
    console.log(`Successfully wrote backup to ${filePath}`);
}
exports.backupCards = backupCards;
function handleCardsFilter(filter, cardsRaw, cliOptions, options) {
    const keywords = ['collection', 'boards', 'title', 'verifier', 'content'];
    let cards = cardsRaw.map((card) => guruClient_1.default._convertCardModel(card));
    if (!filter) {
        if (options === null || options === void 0 ? void 0 : options.raw)
            return cardsRaw;
        return cards;
    }
    const parsed = search_query_parser_1.default.parse(filter, {
        keywords,
        alwaysArray: true,
        tokenize: true,
        offsets: false,
    }); // override to allow iteration without type errors
    if (Object.keys(parsed).includes('boards') && !Object.keys(parsed).includes('collection')) {
        console.log('Please add "collection:example" to filter when filtering for boards');
        process.exit();
    }
    let reFlags = '';
    if (cliOptions.ignoreCase)
        reFlags += 'i';
    for (const keyword of keywords) {
        if (parsed[keyword]) {
            for (const value of parsed[keyword]) {
                const matcher = new RegExp(value, reFlags);
                cards = cards.filter((card) => matcher.test(card[keyword]));
            }
        }
    }
    if (options === null || options === void 0 ? void 0 : options.raw) {
        const rawCardsFiltered = cards.map((card) => cardsRaw.find((cardRaw) => cardRaw.id === card.id));
        return rawCardsFiltered;
    }
    return cards;
}
exports.handleCardsFilter = handleCardsFilter;
